@@ -480,23 +480,43 @@ error:
 int
 _CBOR2_init_re_compile(void)
 {
-    PyObject *re;
+    PyObject *re = NULL;
 
     // import re
     // datestr_re = re.compile("long-date-time-regex...")
     re = PyImport_ImportModule("re");
     if (!re)
         goto error;
+
     _CBOR2_re_compile = PyObject_GetAttr(re, _CBOR2_str_compile);
-    Py_DECREF(re);
     if (!_CBOR2_re_compile)
         goto error;
+
+    _CBOR2_re_error = PyObject_GetAttrString(re, "error");
+    if (!_CBOR2_re_error) {
+        Py_DECREF(_CBOR2_re_compile);
+        _CBOR2_re_compile = NULL;
+        goto error;
+    }
+
+    _CBOR2_datetimestr_re = PyObject_CallFunctionObjArgs(
+            _CBOR2_re_compile, _CBOR2_str_datetimestr_re, NULL);
+    if (!_CBOR2_datetimestr_re)
+        goto error;
+
     _CBOR2_datestr_re = PyObject_CallFunctionObjArgs(
             _CBOR2_re_compile, _CBOR2_str_datestr_re, NULL);
     if (!_CBOR2_datestr_re)
         goto error;
+
+    _CBOR2_datestr_re = PyObject_CallFunctionObjArgs(
+            _CBOR2_re_compile, _CBOR2_str_datestr_re, NULL);
+    if (!_CBOR2_datestr_re)
+        goto error;
+
     return 0;
 error:
+    Py_XDECREF(re);
     PyErr_SetString(PyExc_ImportError, "unable to import compile from re");
     return -1;
 }
@@ -576,6 +596,27 @@ error:
 }
 
 
+int
+_CBOR2_init_thread_locals(void)
+{
+    PyObject *threading = PyImport_ImportModule("threading");
+    if (!threading)
+        return -1;
+
+    PyObject *local = PyObject_GetAttrString(threading, "local");
+    Py_DECREF(threading);
+    if (!local)
+        return -1;
+
+    _CBOR2_thread_locals = PyObject_CallObject(local, NULL);
+    Py_DECREF(local);
+    if (!_CBOR2_thread_locals)
+        return -1;
+
+    return 0;
+}
+
+
 // Module definition /////////////////////////////////////////////////////////
 
 PyObject *_CBOR2_empty_bytes = NULL;
@@ -588,6 +629,7 @@ PyObject *_CBOR2_str_BytesIO = NULL;
 PyObject *_CBOR2_str_canonical_encoders = NULL;
 PyObject *_CBOR2_str_compile = NULL;
 PyObject *_CBOR2_str_copy = NULL;
+PyObject *_CBOR2_str_datetimestr_re = NULL;
 PyObject *_CBOR2_str_datestr_re = NULL;
 PyObject *_CBOR2_str_Decimal = NULL;
 PyObject *_CBOR2_str_default_encoders = NULL;
@@ -616,6 +658,7 @@ PyObject *_CBOR2_str_prefixlen = NULL;
 PyObject *_CBOR2_str_read = NULL;
 PyObject *_CBOR2_str_s = NULL;
 PyObject *_CBOR2_str_timestamp = NULL;
+PyObject *_CBOR2_str_toordinal = NULL;
 PyObject *_CBOR2_str_timezone = NULL;
 PyObject *_CBOR2_str_update = NULL;
 PyObject *_CBOR2_str_utc = NULL;
@@ -640,9 +683,12 @@ PyObject *_CBOR2_FrozenDict = NULL;
 PyObject *_CBOR2_UUID = NULL;
 PyObject *_CBOR2_Parser = NULL;
 PyObject *_CBOR2_re_compile = NULL;
+PyObject *_CBOR2_re_error = NULL;
+PyObject *_CBOR2_datetimestr_re = NULL;
 PyObject *_CBOR2_datestr_re = NULL;
 PyObject *_CBOR2_ip_address = NULL;
 PyObject *_CBOR2_ip_network = NULL;
+PyObject *_CBOR2_thread_locals = NULL;
 
 PyObject *_CBOR2_default_encoders = NULL;
 PyObject *_CBOR2_canonical_encoders = NULL;
@@ -658,9 +704,11 @@ cbor2_free(PyObject *m)
     Py_CLEAR(_CBOR2_UUID);
     Py_CLEAR(_CBOR2_Parser);
     Py_CLEAR(_CBOR2_re_compile);
+    Py_CLEAR(_CBOR2_datetimestr_re);
     Py_CLEAR(_CBOR2_datestr_re);
     Py_CLEAR(_CBOR2_ip_address);
     Py_CLEAR(_CBOR2_ip_network);
+    Py_CLEAR(_CBOR2_thread_locals);
     Py_CLEAR(_CBOR2_CBOREncodeError);
     Py_CLEAR(_CBOR2_CBOREncodeTypeError);
     Py_CLEAR(_CBOR2_CBOREncodeValueError);
@@ -943,6 +991,7 @@ PyInit__cbor2(void)
     INTERN_STRING(read);
     INTERN_STRING(s);
     INTERN_STRING(timestamp);
+    INTERN_STRING(toordinal);
     INTERN_STRING(timezone);
     INTERN_STRING(update);
     INTERN_STRING(utc);
@@ -954,13 +1003,16 @@ PyInit__cbor2(void)
     if (!_CBOR2_str_utc_suffix &&
             !(_CBOR2_str_utc_suffix = PyUnicode_InternFromString("+00:00")))
         goto error;
-    if (!_CBOR2_str_datestr_re &&
-            !(_CBOR2_str_datestr_re = PyUnicode_InternFromString(
+    if (!_CBOR2_str_datetimestr_re &&
+        !(_CBOR2_str_datetimestr_re = PyUnicode_InternFromString(
                     "^(\\d{4})-(\\d\\d)-(\\d\\d)T"     // Y-m-d
                     "(\\d\\d):(\\d\\d):(\\d\\d)"       // H:M:S
                     "(?:\\.(\\d{1,6})\\d*)?"           // .uS
                     "(?:Z|([+-]\\d\\d):(\\d\\d))$")))  // +-TZ
         goto error;
+    if (!_CBOR2_str_datestr_re &&
+        !(_CBOR2_str_datestr_re = PyUnicode_InternFromString("^(\\d{4})-(\\d\\d)-(\\d\\d)")))  // Y-m-d
+        goto error;
     if (!_CBOR2_empty_bytes &&
             !(_CBOR2_empty_bytes = PyBytes_FromStringAndSize(NULL, 0)))
         goto error;
