@@ -213,8 +213,9 @@ def test_special(impl, special_values):
 @pytest.mark.parametrize(
     "payload, expected",
     [
-        ("40", b""),
-        ("4401020304", b"\x01\x02\x03\x04"),
+        pytest.param("40", b"", id="blank"),
+        pytest.param("4401020304", b"\x01\x02\x03\x04", id="short"),
+        pytest.param("5a00011170" + "12" * 70000, b"\x12" * 70000, id="long"),
     ],
 )
 def test_binary(impl, payload, expected):
@@ -484,14 +485,20 @@ def test_datetime_value_too_large(impl):
     with pytest.raises(impl.CBORDecodeError) as excinfo:
         impl.loads(unhexlify("c11b1616161616161616161616161616"))
 
-    assert isinstance(excinfo.value.__cause__, OSError)
+    assert excinfo.value.__cause__ is not None
 
 
 def test_datetime_date_out_of_range(impl):
     with pytest.raises(impl.CBORDecodeError) as excinfo:
         impl.loads(unhexlify("a6c11b00002401001b000000000000ff00"))
 
-    cause_exc_class = OSError if platform.system() == "Windows" else ValueError
+    if sys.maxsize == 2147483647:
+        cause_exc_class = OverflowError
+    elif platform.system() == "Windows":
+        cause_exc_class = OSError
+    else:
+        cause_exc_class = ValueError
+
     assert isinstance(excinfo.value.__cause__, cause_exc_class)
 
 
@@ -938,11 +945,11 @@ def test_decimal_payload_unpacking(impl, data, expected):
     "payload",
     [
         pytest.param(
-            unhexlify("5b7fffffffffffff00"),
+            unhexlify("41"),
             id="bytestring",
         ),
         pytest.param(
-            unhexlify("7b7fffffffffffff00"),
+            unhexlify("61"),
             id="unicode",
         ),
     ],
